
# Slot: nodes_column_number


The number of the column of the node file from where to load the node names.

URI: [https://w3id.org/neat/ensmallenRunConfig__nodes_column_number](https://w3id.org/neat/ensmallenRunConfig__nodes_column_number)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
